@@ -4,6 +4,8 @@ from io import BytesIO
 from telegram import (Update)
 from telegram.ext import (CallbackContext)
 
+from digitalguide.whatsapp.WhatsAppUpdate import WhatsAppUpdate
+
 def generate_gif(im1, im2):
     im1 = im1.resize((round(im2.size[0]*1), round(im2.size[1]*1)))
     im1 = im1.convert(im2.mode)
@@ -47,5 +49,11 @@ def telegram_eval_gif_generation(update: Update, context: CallbackContext, pictu
 
     update.message.reply_document(gif)
 
+def whatsapp_eval_gif_generation(client, update: WhatsAppUpdate, context, picture):
+    pass
+
 telegram_action_functions = {"eval_gif_generation": telegram_eval_gif_generation,
+                    }
+
+whatsapp_action_functions = {"eval_gif_generation": whatsapp_eval_gif_generation,
                     }
\ No newline at end of file
