@@ -1,29 +1,32 @@
 
 import re
+import os
+import requests
 
-def readActions(format_inhalt_list, messanger="Telegram"):
+def readActions(format_inhalt_list, messanger="Telegram", asset_url=""):
     actions = []
     for format, inhalt in format_inhalt_list:
         
         format_split = format.split(" - ")
         if len(format_split) == 2 and format_split[1] != messanger:
-            pass
+            continue
         elif len(format_split) == 2:
             format = format_split[0]
 
         action = {}
 
         if format == "Textnachricht":
-            inhalt = inhalt.replace(".", "\.")
-            inhalt = inhalt.replace("(", "\(")
-            inhalt = inhalt.replace(")", "\)")
-            inhalt = inhalt.replace("!", "\!")
-            inhalt = inhalt.replace("?", "\?")
-            inhalt = inhalt.replace("-", "\-")
-            inhalt = inhalt.replace("+", "\+")
-            inhalt = inhalt.replace("#", "\#")
+            if messanger =="Telegram":
+                inhalt = inhalt.replace(".", "\.")
+                inhalt = inhalt.replace("(", "\(")
+                inhalt = inhalt.replace(")", "\)")
+                inhalt = inhalt.replace("!", "\!")
+                inhalt = inhalt.replace("?", "\?")
+                inhalt = inhalt.replace("-", "\-")
+                inhalt = inhalt.replace("+", "\+")
+                inhalt = inhalt.replace("#", "\#")
 
-            action["parse_mode"] = "MarkdownV2"
+                action["parse_mode"] = "MarkdownV2"
 
             action["type"] = "message"
             action["text"] = inhalt
@@ -34,24 +37,45 @@ def readActions(format_inhalt_list, messanger="Telegram"):
 
             match = re.search(regex, inhalt)
             if match:
-                action["file"] = "assets/" + match.group('file')
+                action["url"] = os.path.join(asset_url, match.group('file'))
+                if requests.get(action["url"]).status_code != 200:
+                    print("Die angegebenen Datei ({}) konnte nicht unter der Asset URL ({}) gefunden werden.".format(
+                    match.group('file'), asset_url))
                 action["title"] = match.group('name')
                 action["performer"] = match.group('performer')
             else:
-                action["file"] = "assets/platzhalter.mp3"
+                action["url"] = os.path.join(asset_url, "platzhalter.mp3")
                 action["title"] = inhalt
                 action["performer"] = "🤖"
 
+        elif format == "Sprachnachricht":
+            action["type"] = "voice"
+            regex = r"Datei: (?P<file>.*)\nAnzeigename: (?P<name>.*)"
+
+            match = re.search(regex, inhalt)
+            if match:
+                action["url"] = os.path.join(asset_url, match.group('file'))
+                if requests.get(action["url"]).status_code != 200:
+                    print("Die angegebenen Datei ({}) konnte nicht unter der Asset URL ({}) gefunden werden.".format(
+                    match.group('file'), asset_url))
+                action["caption"] = match.group('name')
+            else:
+                action["url"] = os.path.join(asset_url, "platzhalter.mp3")
+                action["caption"] = inhalt
+
         elif format == "Foto":
             action["type"] = "photo"
             regex = r"Datei: (?P<file>.*)\nAnzeigename: (?P<name>.*)"
 
             match = re.search(regex, inhalt)
             if match:
-                action["file"] = "assets/" + match.group('file')
+                action["url"] = os.path.join(asset_url, match.group('file'))
+                if requests.get(action["url"]).status_code != 200:
+                    print("Die angegebene Datei ({}) konnte nicht unter der Asset URL ({}) gefunden werden.".format(
+                    match.group('file'), asset_url))
                 action["caption"] = match.group('name')
             else:
-                action["file"] = "assets/platzhalter.png"
+                action["url"] = os.path.join(asset_url, "platzhalter.png")
                 action["caption"] = inhalt
 
         elif format == "GIF":
@@ -60,10 +84,13 @@ def readActions(format_inhalt_list, messanger="Telegram"):
 
             match = re.search(regex, inhalt)
             if match:
-                action["file"] = "assets/" + match.group('file')
+                action["url"] = os.path.join(asset_url, match.group('file'))
+                if requests.get(action["url"]).status_code != 200:
+                    print("Die angegebene Datei ({}) konnte nicht unter der Asset URL ({}) gefunden werden.".format(
+                    match.group('file'), asset_url))
                 action["caption"] = match.group('name')
             else:
-                action["file"] = "assets/platzhalter.png"
+                action["url"] = os.path.join(asset_url, "platzhalter.png")
                 action["caption"] = inhalt
 
         elif format == "GPS":
@@ -83,7 +110,10 @@ def readActions(format_inhalt_list, messanger="Telegram"):
 
             match = re.search(regex, inhalt)
             if match:
-                action["file"] = "assets/" + match.group('file')
+                action["url"] = os.path.join(asset_url, match.group('file'))
+                if requests.get(action["url"]).status_code != 200:
+                    print("Die angegebene Datei ({}) konnte nicht unter der Asset URL ({}) gefunden werden.".format(
+                    match.group('file'), asset_url))
                 action["caption"] = match.group('caption')
 
         elif format == "Sticker":
@@ -115,6 +145,7 @@ def readActions(format_inhalt_list, messanger="Telegram"):
         else:
             print("Das angegebene Format ({}) ist nicht bekannt".format(format))
 
-        actions.append(action)
+        if action:
+            actions.append(action)
 
     return actions
